<?php
namespace Aura\Framework\Web\Controller;

use Aura\Framework\Inflect;
use Aura\Framework\Signal\Manager as SignalManager;
use Aura\Framework\System;
use Aura\Framework\Web\Renderer\AuraViewTwoStep as Renderer;
use Aura\Router\Map as RouterMap;
use Aura\Router\DefinitionFactory;
use Aura\Router\RouteFactory;
use Aura\Signal\HandlerFactory;
use Aura\Signal\ResultCollection;
use Aura\Signal\ResultFactory;
use Aura\View\EscaperFactory;
use Aura\View\FormatTypes;
use Aura\View\HelperLocator;
use Aura\View\Template;
use Aura\View\TemplateFinder;
use Aura\View\TwoStep;
use Aura\Web\Context;
use Aura\Web\Accept;
use Aura\Web\Response;

/**
 * Test class for Page.
 * Generated by PHPUnit on 2011-05-27 at 11:01:03.
 */
abstract class AbstractPageTest extends \PHPUnit_Framework_TestCase
{
    protected $page_class;

    protected function newPage($params = [])
    {
        // context
        $context            = new Context($GLOBALS);
        
        // accept
        $accept             = new Accept($_SERVER);
        
        // web response dto
        $response           = new Response;
        
        // signal manager
        $signal             = new SignalManager(new HandlerFactory, new ResultFactory, new ResultCollection);
        
        // two step view
        $escaper_factory    = new EscaperFactory;
        $template_finder    = new TemplateFinder;
        $helper_locator     = new HelperLocator;
        $template           = new Template($escaper_factory, $template_finder, $helper_locator);
        $format_types       = new FormatTypes;
        $twostep            = new TwoStep($template, $format_types);
        
        // renderer
        $renderer           = new Renderer($twostep, new Inflect, $accept);
        
        // page
        $class = $this->page_class;
        $page = new $class(
            $context,
            $accept,
            $response,
            $signal,
            $renderer,
            $params
        );
        
        // add router to page
        $router = new RouterMap(new DefinitionFactory, new RouteFactory);
        $page->setRouter($router);
        
        // add system to page; use the real system
        // system/package/Aura.Framework/Web/Controller/AbstractPageTest.php
        $root = dirname(dirname(dirname(dirname(__DIR__))));
        $system = new System($root);
        $page->setSystem($system);
        
        // done!
        return $page;
    }
    
    public function testGetLayout()
    {
        $page = $this->newPage();
        $this->assertNull($page->getLayout());
    }
    
    public function testGetView()
    {
        $page = $this->newPage();
        $this->assertNull($page->getView());
    }
}
